#
# Copyright 2023 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "storage"
"""
from delphixpy.v1_11_20.web.storage import objectStorage
from delphixpy.v1_11_20.web.storage import remove
from delphixpy.v1_11_20.web.storage import iscsi
from delphixpy.v1_11_20.web.storage import test
from delphixpy.v1_11_20.web.storage import device
from delphixpy.v1_11_20.web.storage import scrub
